Crate nextsql_backend_rust_runtime

Crate nextsql_backend_rust_runtime 

Modules

tokio_postgres_impl

Traits

Client
Trait for executing SQL queries against a database. Uses impl Future instead of async_trait to avoid proc macro compile overhead.
Row
Trait for reading typed values from a database result row.
ToSqlParam
Trait for values that can be bound as SQL query parameters.